@@ -102,7 +102,7 @@ struct ID3_TAG
 /**************************************************************************************************
 Footer (and header) flags
 **************************************************************************************************/
-#define APE_TAG_FLAG_CONTAINS_HEADER            ((unsigned int) 1 << 31)
+#define APE_TAG_FLAG_CONTAINS_HEADER            (static_cast<unsigned int>(1 << 31))
 #define APE_TAG_FLAG_CONTAINS_FOOTER            (1 << 30)
 #define APE_TAG_FLAG_IS_HEADER                  (1 << 29)
 
@@ -122,7 +122,6 @@ Tag field flags
 /**************************************************************************************************
 The footer at the end of APE tagged files (can also optionally be at the front of the tag)
 **************************************************************************************************/
-#ifdef APE_ENABLE_TAG_FOOTER
 #define APE_TAG_FOOTER_BYTES    32
 class APE_TAG_FOOTER
 {
@@ -167,7 +166,6 @@ public:
         return bValid ? true : false;
     }
 };
-#endif
 
 /**************************************************************************************************
 CAPETagField class (an APE tag is an array of these)
